@@ -46,7 +46,7 @@ column have their own datatype.) This means that you can just specify
 ``len(datatypes)<ncols`` then datatype assignment will cycle across a
 row.  E.g., if you provide 10 columns of data with ``datatypes=[0,1]``
 then you will have 5 columns of datatype 0 and 5 columns of datatype
-1, alternating.  Correspoding to this specification, you should provide
+1, alternating.  Corresponding to this specification, you should provide
 a list of two ``data_fmts`` and a list of two ``data_aligns``.
 
 Cells can be assigned labels as their `datatype` attribute.
@@ -82,7 +82,7 @@ Potential problems for Python 3
 :change: 2010-05-06 add `label_cells` to `SimpleTable`
 """
 
-from statsmodels.compat.python import lmap, lrange, iteritems
+from statsmodels.compat.python import lmap, lrange
 
 from itertools import cycle, zip_longest
 import csv
@@ -97,7 +97,7 @@ def csv2st(csvfile, headers=False, stubs=False, title=None):
     Can also supply headers and stubs as tuples of strings.
     """
     rows = list()
-    with open(csvfile, 'r') as fh:
+    with open(csvfile, 'r', encoding="utf-8") as fh:
         reader = csv.reader(fh)
         if headers is True:
             headers = next(reader)
@@ -115,9 +115,8 @@ def csv2st(csvfile, headers=False, stubs=False, title=None):
                     rows.append(row)
         if stubs is False:
             stubs = ()
-    nrows = len(rows)
     ncols = len(rows[0])
-    if any(nrows != ncols for row in rows):
+    if any(len(row) != ncols for row in rows):
         raise IOError('All rows of CSV file must have same length.')
     return SimpleTable(data=rows, headers=headers, stubs=stubs)
 
@@ -180,7 +179,9 @@ class SimpleTable(list):
             general formatting options
         """
         self.title = title
-        self._datatypes = datatypes or lrange(len(data[0]))
+        self._datatypes = datatypes
+        if self._datatypes is None:
+            self._datatypes = [] if len(data) == 0 else lrange(len(data[0]))
         # start with default formatting
         self._txt_fmt = default_txt_fmt.copy()
         self._latex_fmt = default_latex_fmt.copy()
@@ -219,6 +220,9 @@ class SimpleTable(list):
     def _repr_html_(self, **fmt_dict):
         return self.as_html(**fmt_dict)
 
+    def _repr_latex_(self, center=True, **fmt_dict):
+        return self.as_latex_tabular(center, **fmt_dict)
+
     def _add_headers_stubs(self, headers, stubs):
         """Return None.  Adds headers and stubs to table,
         if these were provided at initialization.
@@ -327,11 +331,11 @@ class SimpleTable(list):
     def get_colwidths(self, output_format, **fmt_dict):
         """Return list, the widths of each column."""
         call_args = [output_format]
-        for k, v in sorted(iteritems(fmt_dict)):
+        for k, v in sorted(fmt_dict.items()):
             if isinstance(v, list):
                 call_args.append((k, tuple(v)))
             elif isinstance(v, dict):
-                call_args.append((k, tuple(sorted(iteritems(v)))))
+                call_args.append((k, tuple(sorted(v.items()))))
             else:
                 call_args.append((k, v))
         key = tuple(call_args)
@@ -627,7 +631,7 @@ class Row(list):
         return [cell.data for cell in self]
 
 
-class Cell(object):
+class Cell:
     """Provides a table cell.
     A cell can belong to a Row, but does not have to.
     """
@@ -720,7 +724,13 @@ class Cell(object):
             data_fmts = [data_fmt]
         if isinstance(datatype, int):
             datatype = datatype % len(data_fmts)  # constrain to indexes
-            content = data_fmts[datatype] % (data,)
+            data_fmt = data_fmts[datatype]
+            if isinstance(data_fmt, str):
+                content = data_fmt % (data,)
+            elif callable(data_fmt):
+                content = data_fmt(data)
+            else:
+                raise TypeError("Must be a string or a callable")
             if datatype == 0:
                 content = self._latex_escape(content, fmt, output_format)
         elif datatype in fmt:
