@@ -5,7 +5,7 @@ Created on Mon Jan 11 11:04:23 2010
 Author: josef-pktd
 License: BSD
 
-This is a new version, I didn't look at the old version again, but similar
+This is a new version, I did not look at the old version again, but similar
 ideas.
 
 not copied/cleaned yet:
@@ -28,12 +28,8 @@ Extensions
 see also VAR section in Notes.txt
 
 """
-from __future__ import print_function
 import numpy as np
-from numpy.testing import assert_equal
 from scipy import signal
-#might not (yet) need the following
-from scipy.signal.signaltools import _centered as trim_centered
 
 from statsmodels.tsa.tsatools import lagmat
 
@@ -41,8 +37,8 @@ from statsmodels.tsa.tsatools import lagmat
 def varfilter(x, a):
     '''apply an autoregressive filter to a series x
 
-    Warning: I just found out that convolve doesn't work as I
-       thought, this likely doesn't work correctly for
+    Warning: I just found out that convolve does not work as I
+       thought, this likely does not work correctly for
        nvars>3
 
 
@@ -127,13 +123,12 @@ def varfilter(x, a):
 
     elif a.ndim == 3:
         # case: vector autoregressive with lag matrices
-#        #not necessary:
-#        if np.any(a.shape[1:] != nvar):
-#            raise ValueError('if 3d shape of a has to be (nobs,nvar,nvar)')
+        # Note: we must have shape[1] == shape[2] == nvar
         yf = signal.convolve(x[:,:,None], a)
         yvalid = yf[ntrim:-ntrim, yf.shape[1]//2,:]
         return yvalid
 
+
 def varinversefilter(ar, nobs, version=1):
     '''creates inverse ar filter (MA representation) recursively
 
@@ -150,13 +145,13 @@ def varinversefilter(ar, nobs, version=1):
 
     Parameters
     ----------
-    ar : array, (nlags,nvars,nvars)
+    ar : ndarray, (nlags,nvars,nvars)
         matrix lagpolynomial, currently no exog
         first row should be identity
 
     Returns
     -------
-    arinv : array, (nobs,nvars,nvars)
+    arinv : ndarray, (nobs,nvars,nvars)
 
 
     Notes
@@ -185,6 +180,7 @@ def varinversefilter(ar, nobs, version=1):
 
     return arinv
 
+
 def vargenerate(ar, u, initvalues=None):
     '''generate an VAR process with errors u
 
@@ -280,6 +276,7 @@ def padone(x, front=0, back=0, axis=0, fillvalue=0):
     out[tuple(myslice)] = x
     return out
 
+
 def trimone(x, front=0, back=0, axis=0):
     '''trim number of array elements along one axis
 
@@ -308,13 +305,13 @@ def trimone(x, front=0, back=0, axis=0):
     return x[tuple(myslice)]
 
 
-
 def ar2full(ar):
     '''make reduced lagpolynomial into a right side lagpoly array
     '''
     nlags, nvar,nvarex = ar.shape
     return np.r_[np.eye(nvar,nvarex)[None,:,:],-ar]
 
+
 def ar2lhs(ar):
     '''convert full (rhs) lagpolynomial into a reduced, left side lagpoly array
 
@@ -323,8 +320,7 @@ def ar2lhs(ar):
     return -ar[1:]
 
 
-
-class _Var(object):
+class _Var:
     '''obsolete VAR class, use tsa.VAR instead, for internal use only
 
 
@@ -346,13 +342,12 @@ class _Var(object):
         self.y = y
         self.nobs, self.nvars = y.shape
 
-
     def fit(self, nlags):
         '''estimate parameters using ols
 
         Parameters
         ----------
-        nlags : integer
+        nlags : int
             number of lags to include in regression, same for all variables
 
         Returns
@@ -440,7 +435,7 @@ class _Var(object):
         return vargenerate(self.arhat, u, initvalues=self.y)
 
 
-class VarmaPoly(object):
+class VarmaPoly:
     '''class to keep track of Varma polynomial format
 
 
@@ -479,13 +474,12 @@ class VarmaPoly(object):
         self.hasexog = nvarall > nvars
         self.arm1 = -ar[1:]
 
-
     #@property
     def vstack(self, a=None, name='ar'):
         '''stack lagpolynomial vertically in 2d array
 
         '''
-        if not a is None:
+        if a is not None:
             a = a
         elif name == 'ar':
             a = self.ar
@@ -500,7 +494,7 @@ class VarmaPoly(object):
         '''stack lagpolynomial horizontally in 2d array
 
         '''
-        if not a is None:
+        if a is not None:
             a = a
         elif name == 'ar':
             a = self.ar
@@ -515,7 +509,7 @@ class VarmaPoly(object):
         '''stack lagpolynomial vertically in 2d square array with eye
 
         '''
-        if not a is None:
+        if a is not None:
             a = a
         elif name == 'ar':
             a = self.ar
@@ -551,7 +545,7 @@ class VarmaPoly(object):
 
         Returns
         -------
-        isstationary : boolean
+        isstationary : bool
 
         *attaches*
 
@@ -563,7 +557,7 @@ class VarmaPoly(object):
         formula taken from NAG manual
 
         '''
-        if not a is None:
+        if a is not None:
             a = a
         else:
             if self.isstructured:
@@ -580,7 +574,7 @@ class VarmaPoly(object):
 
         Returns
         -------
-        isinvertible : boolean
+        isinvertible : bool
 
         *attaches*
 
@@ -592,7 +586,7 @@ class VarmaPoly(object):
         formula taken from NAG manual
 
         '''
-        if not a is None:
+        if a is not None:
             a = a
         else:
             if self.isindependent:
@@ -604,7 +598,6 @@ class VarmaPoly(object):
             self.maeigenvalues = np.array([], np.complex)
             return True
 
-
         amat = self.stacksquare(a)
         ev = np.sort(np.linalg.eigvals(amat))[::-1]
         self.maeigenvalues = ev
@@ -633,8 +626,6 @@ class VarmaPoly(object):
         return a
 
 
-
-
 if __name__ == "__main__":
     # some example lag polynomials
     a21 = np.array([[[ 1. ,  0. ],
@@ -682,13 +673,11 @@ if __name__ == "__main__":
     arhat = ar2full(bhat)
     #print(maxabs(arhat - a22)
 
-
     v = _Var(ar2s)
     v.fit(1)
     v.forecast()
     v.forecast(25)[-30:]
 
-
     ar23 = np.array([[[ 1. ,  0. ],
                      [ 0. ,  1. ]],
 
